local function file_exists(name)
  local f = io.open(name, 'r')
  if f ~= nil then io.close(f); return true
  else return false end
end

--- Create a standalone LaTeX document which contains only the TikZ picture.
--- Convert to png via Imagemagick.
local function tikz2image(src, outfile)
  local f = io.open("tmp.tex", 'w')
  f:write("\\documentclass[tikz,convert={outfile=" .. outfile .. "}]{standalone}")
  f:write("\\usepackage{tikz-cd}")
  f:write("\\begin{document}\n")
  f:write(src)
  f:write("\n\\end{document}\n")
  f:close()
  os.execute("pdflatex -shell-escape tmp.tex")
end


function RawBlock(el)
  -- Don't alter element if it's not a tikzpicture environment
  if not el.text:match'^\\begin{tikzcd}' then
    return pandoc.read(el.text, 'latex').blocks
  end  
  local fname = pandoc.sha1(el.text) .. ".svg"
  local out_file = "pages/" .. fname
  if not file_exists(out_file) then
    tikz2image(el.text, out_file)
  end
  return pandoc.Para({pandoc.Image({}, '/~xkucerak/' .. fname)})
end

